Activity and ActType 用户动态类
===============================

..  autoclass:: zhihu.activity.Activity
    :members:
    :special-members: __init__

..  autoclass:: zhihu.acttype.ActType
    :members:
    :special-members: __init__
